﻿
using Common.Logging;
using Quartz;
using Quartz.Impl;
using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace SimpleSchedulerApp
{
    class Program
    {
        static void Main(string[] args)
        {
            LogManager.Adapter = new Common.Logging.Simple.TraceLoggerFactoryAdapter() { Level = LogLevel.All };

            try
            {
                //1.首先创建一个作业调度池
                var properties = new NameValueCollection();
                //存储类型
                properties["quartz.jobStore.type"] = "Quartz.Impl.AdoJobStore.JobStoreTX, Quartz";

                //驱动类型
                properties["quartz.jobStore.driverDelegateType"] = "Quartz.Impl.AdoJobStore.SqlServerDelegate, Quartz";                //数据源名称
                properties["quartz.jobStore.dataSource"] = "myDS";

                //连接字符串
                properties["quartz.dataSource.myDS.connectionString"] = @"server=.;Initial Catalog=quartz;Integrated Security=True";
                //sqlserver版本
                properties["quartz.dataSource.myDS.provider"] = "SqlServer-20";

                //是否集群
                properties["quartz.jobStore.clustered"] = "true";
                properties["quartz.scheduler.instanceId"] = "AUTO";

                var factory = new StdSchedulerFactory(properties);

                IScheduler scheduler = factory.GetScheduler();

                scheduler.Start();

                var jobKey = JobKey.Create("myjob", "group");

                if (scheduler.CheckExists(jobKey))
                {
                    Console.WriteLine("当前job已经存在，无需调度:{0}", jobKey.ToString());
                }
                else
                {
                    IJobDetail job = JobBuilder.Create<HelloJob>()
                           .WithDescription("使用quartz进行持久化存储")
                           .StoreDurably()
                           .RequestRecovery()
                           .WithIdentity(jobKey)
                           .UsingJobData("count", 1)
                           .Build();

                    ITrigger trigger = TriggerBuilder.Create().WithSimpleSchedule(x => x.WithIntervalInSeconds(2).RepeatForever())
                                                              .Build();

                    scheduler.ScheduleJob(job, trigger);

                    Console.WriteLine("调度进行中！！！");
                }
            }
            catch (SchedulerException se)
            {
                Console.WriteLine(se);
            }

            Console.WriteLine("Press any key to close the application");
            Console.ReadKey();
        }
    }
}
